"""Create index for solved on version id

Revision ID: 7d970baad7f2
Revises: b91c11e75551
Create Date: 2020-01-13 22:40:23.898138+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "7d970baad7f2"
down_revision = "b91c11e75551"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index("solved_version_id_idx", "solved", ["version_id"], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("solved_version_id_idx", table_name="solved")
    # ### end Alembic commands ###
