"""Extend Python package information stored in the database

Revision ID: 95c40432360f
Revises: 894ddaef0c43
Create Date: 2021-07-01 12:51:03.294947+00:00

"""
from alembic import op
from sqlalchemy.sql import text
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "95c40432360f"
down_revision = "894ddaef0c43"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    conn = op.get_bind()
    conn.execute(text("DELETE FROM identified"))
    op.add_column("identified", sa.Column("location", sa.Text(), nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("identified", "location")
    # ### end Alembic commands ###
