"""Remove string size limitation from marker and extras

Revision ID: 9fea7ca59f56
Revises: fd7771734460
Create Date: 2020-01-03 11:41:38.419935+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9fea7ca59f56"
down_revision = "fd7771734460"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("depends_on", "marker", type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column("depends_on", "extra", type_=sa.Text, existing_type=sa.VARCHAR)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("depends_on", "marker", type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column("depends_on", "extra", type_=sa.String, existing_type=sa.VARCHAR)
    # ### end Alembic commands ###
